## Autenticação

O Lazy Ninja inclui um módulo JWT opcional que pode ser ativado por API.

Destaques:

- Modo stateless ou stateful
- Identificadores de login configuráveis
- Suporte a cookies
- Hooks para login/registro/refresh/logout

Veja o [Guia de Autenticação](auth-guide.md).
